@@ -4,7 +4,8 @@ use warnings;
 use autodie;
 
 use App::Fasops -command;
-use App::Fasops::Common qw(:all);
+use App::RL::Common;
+use App::Fasops::Common;
 
 use constant abstract => 'realign alignments';
 
@@ -66,7 +67,7 @@ sub execute {
             $line = $in_fh->getline;
         }
         if ( ( $line eq '' or $line =~ /^\s+$/ ) and $content ne '' ) {
-            my $info_of = parse_block($content);
+            my $info_of = App::Fasops::Common::parse_block($content);
             $content = '';
 
             if ( $opt->{msa} ne "none" ) {
@@ -76,16 +77,16 @@ sub execute {
                 for my $key (@keys) {
                     push @seqs, $info_of->{$key}{seq};
                 }
-                my $refined = align_seqs( \@seqs, $opt->{msa} );
+                my $refined = App::Fasops::Common::align_seqs( \@seqs, $opt->{msa} );
 
                 for my $i ( 0 .. $#keys ) {
-                    printf {$out_fh} ">%s\n", encode_header( $info_of->{ $keys[$i] } );
+                    printf {$out_fh} ">%s\n", App::RL::Common::encode_header( $info_of->{ $keys[$i] } );
                     printf {$out_fh} "%s\n",  uc $refined->[$i];
                 }
             }
             else {
                 for my $key ( keys %{$info_of} ) {
-                    printf {$out_fh} ">%s\n", encode_header( $info_of->{ $key } );
+                    printf {$out_fh} ">%s\n", App::RL::Common::encode_header( $info_of->{ $key } );
                     printf {$out_fh} "%s\n",  $info_of->{$key}{seq};
                 }
             }
