@@ -1,7 +1,11 @@
 package App::Fasops::Command::separate;
+use strict;
+use warnings;
+use autodie;
 
 use App::Fasops -command;
-use App::Fasops::Common qw(:all);
+use App::RL::Common;
+use App::Fasops::Common;
 
 use constant abstract => 'separate blocked fasta files by species';
 
@@ -69,7 +73,7 @@ sub execute {
                 $line = $in_fh->getline;
             }
             if ( ( $line eq '' or $line =~ /^\s+$/ ) and $content ne '' ) {
-                my $info_of = parse_block($content);
+                my $info_of = App::Fasops::Common::parse_block($content);
                 $content = '';
 
                 for my $key ( keys %{$info_of} ) {
@@ -78,18 +82,18 @@ sub execute {
                         $info->{seq} =~ tr/-//d;
                     }
                     if ( $opt->{rc} and $info->{chr_strand} ne "+" ) {
-                        $info->{seq}        = revcom( $info->{seq} );
+                        $info->{seq}        = App::Fasops::Common::revcom( $info->{seq} );
                         $info->{chr_strand} = "+";
                     }
 
                     if ( lc( $opt->{outdir} ) eq "stdout" ) {
-                        print ">" . encode_header($info) . "\n";
+                        print ">" . App::RL::Common::encode_header($info) . "\n";
                         print $info->{seq} . "\n";
                     }
                     else {
                         my $outfile
                             = Path::Tiny::path( $opt->{outdir}, $info->{name} . $opt->{suffix} );
-                        $outfile->append( ">" . encode_header($info) . "\n" );
+                        $outfile->append( ">" . App::RL::Common::encode_header($info) . "\n" );
                         $outfile->append( $info->{seq} . "\n" );
                     }
                 }
