@@ -14,47 +14,13 @@ use Path::Tiny;
 use Tie::IxHash;
 use YAML::Syck;
 
-use base 'Exporter';
-use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS);
-@ISA         = qw(Exporter);
-%EXPORT_TAGS = (
-    all => [
-        qw{
-            read_sizes read_names read_replaces decode_header encode_header parse_block
-            parse_block_header parse_axt_block parse_maf_block revcom seq_length align_seqs
-            },
-    ],
-);
-@EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-sub read_sizes {
-    my $file       = shift;
-    my $remove_chr = shift;
-
-    tie my %length_of, "Tie::IxHash";
-    my @lines = path($file)->lines( { chomp => 1 } );
-    for (@lines) {
-        my ( $key, $value ) = split /\t/;
-        $key =~ s/chr0?// if $remove_chr;
-        $length_of{$key} = $value;
-    }
-
-    return \%length_of;
-}
-
-sub read_names {
-    my $file = shift;
-
-    my @lines = path($file)->lines( { chomp => 1 } );
-
-    return \@lines;
-}
+use App::RL::Common;
 
 sub read_replaces {
     my $file = shift;
 
     tie my %replace, "Tie::IxHash";
-    my @lines = path($file)->lines( { chomp => 1 } );
+    my @lines = Path::Tiny::path($file)->lines( { chomp => 1 } );
     for (@lines) {
         my @fields = split /\t/;
         if ( @fields >= 1 ) {
@@ -66,104 +32,6 @@ sub read_replaces {
     return \%replace;
 }
 
-sub decode_header {
-    my $header = shift;
-
-    # S288C.chrI(+):27070-29557|species=S288C
-    my $head_qr = qr{
-        (?:(?P<name>[\w_]+)\.)?
-        (?P<chr_name>[\w-]+)
-        (?:\((?P<chr_strand>.+)\))?
-        [\:]                        # spacer
-        (?P<chr_start>\d+)
-        [\_\-]                      # spacer
-        (?P<chr_end>\d+)
-    }xi;
-
-    tie my %info, "Tie::IxHash";
-
-    $header =~ $head_qr;
-    my $name     = $1;
-    my $chr_name = $2;
-
-    if ( defined $name or defined $chr_name ) {
-        %info = (
-            name       => $name,
-            chr_name   => $chr_name,
-            chr_strand => $3,
-            chr_start  => $4,
-            chr_end    => $5,
-        );
-        if ( !defined $info{chr_strand} ) {
-            $info{chr_strand} = '+';
-        }
-        elsif ( $info{chr_strand} eq '1' ) {
-            $info{chr_strand} = '+';
-        }
-        elsif ( $info{chr_strand} eq '-1' ) {
-            $info{chr_strand} = '-';
-        }
-    }
-    else {
-        $name = $header;
-        %info = (
-            name       => $name,
-            chr_name   => undef,
-            chr_strand => undef,
-            chr_start  => undef,
-            chr_end    => undef,
-        );
-    }
-
-    # additional keys
-    if ( $header =~ /\|(.+)/ ) {
-        my @parts = grep {defined} split /;/, $1;
-        for my $part (@parts) {
-            my ( $key, $value ) = split /=/, $part;
-            if ( defined $key and defined $value ) {
-                $info{$key} = $value;
-            }
-        }
-    }
-
-    return \%info;
-}
-
-sub encode_header {
-    my $info           = shift;
-    my $only_essential = shift;
-
-    my $header;
-    $header .= $info->{name};
-    if ( defined $info->{chr_name} ) {
-        $header .= "." . $info->{chr_name};
-    }
-    if ( defined $info->{chr_strand} ) {
-        $header .= "(" . $info->{chr_strand} . ")";
-    }
-    if ( defined $info->{chr_start} ) {
-        $header .= ":" . $info->{chr_start};
-        $header .= "-" . $info->{chr_end};
-    }
-
-    # additional keys
-    if ( !$only_essential ) {
-        my %essential = map { $_ => 1 } qw{name chr_name chr_strand chr_start chr_end seq full_seq};
-        my @parts;
-        for my $key ( sort keys %{$info} ) {
-            if ( !$essential{$key} ) {
-                push @parts, $key . "=" . $info->{$key};
-            }
-        }
-        if (@parts) {
-            my $additional = join ";", @parts;
-            $header .= "|" . $additional;
-        }
-    }
-
-    return $header;
-}
-
 sub parse_block {
     my $block = shift;
 
@@ -179,13 +47,13 @@ sub parse_block {
         my $seq = shift @lines;
         chomp $seq;
 
-        my $info_ref = decode_header($header);
+        my $info_ref = App::RL::Common::decode_header($header);
         $info_ref->{seq} = $seq;
         if ( defined $info_ref->{name} ) {
             $info_of{ $info_ref->{name} } = $info_ref;
         }
         else {
-            my $ess_header = encode_header( $info_ref, 1 );
+            my $ess_header = App::RL::Common::encode_header( $info_ref, 1 );
             $info_of{$ess_header} = $info_ref;
         }
     }
@@ -208,8 +76,8 @@ sub parse_block_header {
         my $seq = shift @lines;
         chomp $seq;
 
-        my $info_ref = decode_header($header);
-        my $ess_header = encode_header( $info_ref, 1 );
+        my $info_ref = App::RL::Common::decode_header($header);
+        my $ess_header = App::RL::Common::encode_header( $info_ref, 1 );
         $info_ref->{seq} = $seq;
         $info_of{$ess_header} = $info_ref;
     }
@@ -443,11 +311,11 @@ sub read_fasta {
     my $filename = shift;
 
     tie my %seq_of, "Tie::IxHash";
-    my @lines = path($filename)->lines;
+    my @lines = Path::Tiny::path($filename)->lines;
 
     my $cur_name;
     for my $line (@lines) {
-        if ( $line =~ /^\>[\w:-]+/ ) {
+        if ( $line =~ /^\>\S+/ ) {
             $line =~ s/\>//;
             chomp $line;
             $cur_name = $line;
@@ -464,4 +332,40 @@ sub read_fasta {
     return \%seq_of;
 }
 
+sub mean {
+    @_ = grep { defined $_ } @_;
+    return 0 unless @_;
+    return $_[0] unless @_ > 1;
+    return List::Util::sum(@_) / scalar(@_);
+}
+
+sub calc_gc_ratio {
+    my $seq_refs = shift;
+
+    my $seq_count = scalar @{$seq_refs};
+
+    my @ratios;
+    for my $i ( 0 .. $seq_count - 1 ) {
+
+        # Count all four bases
+        my $a_count = $seq_refs->[$i] =~ tr/Aa/Aa/;
+        my $g_count = $seq_refs->[$i] =~ tr/Gg/Gg/;
+        my $c_count = $seq_refs->[$i] =~ tr/Cc/Cc/;
+        my $t_count = $seq_refs->[$i] =~ tr/Tt/Tt/;
+
+        my $four_count = $a_count + $g_count + $c_count + $t_count;
+        my $gc_count   = $g_count + $c_count;
+
+        if ( $four_count == 0 ) {
+            next;
+        }
+        else {
+            my $gc_ratio = $gc_count / $four_count;
+            push @ratios, $gc_ratio;
+        }
+    }
+
+    return mean(@ratios);
+}
+
 1;
